/**sequencer is part of JamMo.
License: GPLv2, read more from COPYING

This file is for clutter based gui.
*/
#ifndef _SEQUENCER_H_
#define _SEQUENCER_H_

void start_fullsequencer_gui(ClutterActor* levelview);

gboolean sequencer_change_to_loop_view(TangleActor *actor, gpointer data);
gboolean sequencer_change_to_sequencer_view(TangleActor *actor, gpointer data);
gboolean sequencer_change_to_bottom_view(TangleActor *actor, gpointer data);
void return_to_fullsequencer_gui();
#endif /* _SEQUENCER_H_ */

